@@ -10,23 +10,30 @@
 
 import { Command, flags } from '@oclif/command'
 import { cli } from 'cli-ux'
-import * as notifier from 'node-notifier'
 
 import { CheHelper } from '../../api/che'
-import { cheNamespace } from '../../common-flags'
+import { ChectlContext } from '../../api/context'
+import { cheNamespace, CHE_TELEMETRY } from '../../common-flags'
+import { DEFAULT_ANALYTIC_HOOK_NAME } from '../../constants'
+import { findWorkingNamespace } from '../../util'
 
 export default class Open extends Command {
   static description = 'Open CodeReady Workspaces dashboard'
 
-  static flags = {
+  static flags: flags.Input<any> = {
     help: flags.help({ char: 'h' }),
     chenamespace: cheNamespace,
+    telemetry: CHE_TELEMETRY
   }
 
   async run() {
     const { flags } = this.parse(Open)
+    flags.chenamespace = await findWorkingNamespace(flags)
+    await ChectlContext.init(flags, this)
 
     try {
+      await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Open.id, flags })
+
       const cheHelper = new CheHelper(flags)
       const cheURL = await cheHelper.cheURL(flags.chenamespace)
       const dashboardUrl = `${cheURL}/dashboard/`
@@ -37,11 +44,6 @@ export default class Open extends Command {
       this.error(error)
     }
 
-    notifier.notify({
-      title: 'crwctl',
-      message: 'Command dashboard:open has completed successfully.'
-    })
-
     this.exit(0)
   }
 }
