@@ -11,9 +11,13 @@ import { Command } from '@oclif/command'
 import * as Listr from 'listr'
 
 import { CheHelper } from '../api/che'
+import { CheApiClient } from '../api/che-api-client'
+import { CheServerLoginManager } from '../api/che-login-manager'
 import { KubeHelper } from '../api/kube'
 import { OpenShiftHelper } from '../api/openshift'
-import { DOCS_LINK_AUTH_TO_CHE_SERVER_VIA_OPENID } from '../constants'
+import { VersionHelper } from '../api/version'
+import { CHE_OPERATOR_SELECTOR, DOC_LINK, DOC_LINK_RELEASE_NOTES, OUTPUT_SEPARATOR } from '../constants'
+import { base64Decode } from '../util'
 
 import { KubeTasks } from './kube'
 
@@ -28,10 +32,13 @@ export class CheTasks {
 
   cheNamespace: string
 
-  cheAccessToken: string
+  cheAccessToken: string | undefined
   cheSelector = 'app=codeready,component=codeready'
   cheDeploymentName: string
 
+  dashboardDeploymentName = 'che-dashboard'
+  dashboardSelector = 'app=codeready,component=codeready-dashboard'
+
   keycloakDeploymentName = 'keycloak'
   keycloakSelector = 'app=codeready,component=keycloak'
 
@@ -44,7 +51,7 @@ export class CheTasks {
   pluginRegistryDeploymentName = 'plugin-registry'
   pluginRegistrySelector = 'app=codeready,component=plugin-registry'
 
-  cheOperatorSelector = 'app=codeready-operator'
+  cheConsoleLinkName = 'che'
 
   constructor(flags: any) {
     this.kube = new KubeHelper(flags)
@@ -64,36 +71,38 @@ export class CheTasks {
    *
    * @see che.checkIfCheIsInstalledTasks
    */
-  waitDeployedChe(flags: any, command: Command): ReadonlyArray<Listr.ListrTask> {
+  waitDeployedChe(): ReadonlyArray<Listr.ListrTask> {
     return [
       {
         title: 'PostgreSQL pod bootstrap',
-        skip: () => !flags.multiuser,
         enabled: ctx => ctx.isPostgresDeployed && !ctx.isPostgresReady,
-        task: () => this.kubeTasks.podStartTasks(command, this.postgresSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.postgresSelector, this.cheNamespace)
       },
       {
         title: 'Keycloak pod bootstrap',
-        skip: () => !flags.multiuser,
         enabled: ctx => ctx.isKeycloakDeployed && !ctx.isKeycloakReady,
-        task: () => this.kubeTasks.podStartTasks(command, this.keycloakSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.keycloakSelector, this.cheNamespace)
       },
       {
-        title: 'Devfile registry pod bootstrap',
+        title: 'Devfile Registry pod bootstrap',
         enabled: ctx => ctx.isDevfileRegistryDeployed && !ctx.isDevfileRegistryReady,
-        task: () => this.kubeTasks.podStartTasks(command, this.devfileRegistrySelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.devfileRegistrySelector, this.cheNamespace)
       },
       {
-        title: 'Plugin registry pod bootstrap',
+        title: 'Plug-in Registry pod bootstrap',
         enabled: ctx => ctx.isPluginRegistryDeployed && !ctx.isPluginRegistryReady,
-        task: () => this.kubeTasks.podStartTasks(command, this.pluginRegistrySelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.pluginRegistrySelector, this.cheNamespace)
       },
       {
-        title: 'CodeReady Workspaces pod bootstrap',
+        title: 'CodeReady Workspaces Dashboard pod bootstrap',
+        enabled: ctx => ctx.isDashboardDeployed && !ctx.isDashboardReady,
+        task: () => this.kubeTasks.podStartTasks(this.dashboardSelector, this.cheNamespace)
+      },
+      {
+        title: 'CodeReady Workspaces Server pod bootstrap',
         enabled: ctx => !ctx.isCheReady,
-        task: () => this.kubeTasks.podStartTasks(command, this.cheSelector, this.cheNamespace)
+        task: () => this.kubeTasks.podStartTasks(this.cheSelector, this.cheNamespace)
       },
-      ...this.retrieveEclipseCheUrl(flags),
       ...this.checkEclipseCheStatus()
     ]
   }
@@ -118,6 +127,14 @@ export class CheTasks {
               ctx.isCheStopped = await this.kube.deploymentStopped(this.cheDeploymentName, this.cheNamespace)
             }
 
+            ctx.isDashboardDeployed = await this.kube.deploymentExist(this.dashboardDeploymentName, this.cheNamespace)
+            if (ctx.isDashboardDeployed) {
+              ctx.isDashboardReady = await this.kube.deploymentReady(this.dashboardDeploymentName, this.cheNamespace)
+              if (!ctx.isDashboardReady) {
+                ctx.isDashboardStopped = await this.kube.deploymentStopped(this.dashboardDeploymentName, this.cheNamespace)
+              }
+            }
+
             ctx.isKeycloakDeployed = await this.kube.deploymentExist(this.keycloakDeploymentName, this.cheNamespace)
             if (ctx.isKeycloakDeployed) {
               ctx.isKeycloakReady = await this.kube.deploymentReady(this.keycloakDeploymentName, this.cheNamespace)
@@ -191,8 +208,9 @@ export class CheTasks {
           let cheURL = ''
           try {
             cheURL = await this.che.cheURL(this.cheNamespace)
-            const status = await this.che.getCheServerStatus(cheURL)
-            ctx.isAuthEnabled = await this.che.isAuthenticationEnabled(cheURL)
+            const cheApi = CheApiClient.getInstance(cheURL + '/api')
+            const status = await cheApi.getCheServerStatus()
+            ctx.isAuthEnabled = await cheApi.isAuthenticationEnabled()
             const auth = ctx.isAuthEnabled ? '(auth enabled)' : '(auth disabled)'
             task.title = `${task.title}...${status} ${auth}`
           } catch (error) {
@@ -204,43 +222,62 @@ export class CheTasks {
   }
 
   /**
-   * Returns tasks list which scale down all CodeReady Workspaces components which are deployed.
+   * Returns tasks list which scale up all CodeReady Workspaces components which are deployed.
    * It requires {@link this#checkIfCheIsInstalledTasks} to be executed before.
    *
    * @see [CheTasks](#checkIfCheIsInstalledTasks)
    */
-  scaleCheUpTasks(_command: Command): ReadonlyArray<Listr.ListrTask> {
+  scaleCheUpTasks(): ReadonlyArray<Listr.ListrTask> {
     return [
       {
-        title: 'Scaling up CodeReady Workspaces Deployments',
-        enabled: (ctx: any) => ctx.isCheDeployed,
-        task: async (ctx: any, task: any) => {
-          if (ctx.isPostgresDeployed) {
-            await this.kube.scaleDeployment(this.postgresDeploymentName, this.cheNamespace, 1)
-          }
-          if (ctx.isKeycloakDeployed) {
-            await this.kube.scaleDeployment(this.keycloakDeploymentName, this.cheNamespace, 1)
-          }
-          if (ctx.isPluginRegistryDeployed) {
-            await this.kube.scaleDeployment(this.pluginRegistryDeploymentName, this.cheNamespace, 1)
-          }
-          if (ctx.isDevfileRegistryDeployed) {
-            await this.kube.scaleDeployment(this.devfileRegistryDeploymentName, this.cheNamespace, 1)
-          }
-          await this.kube.scaleDeployment(this.cheDeploymentName, this.cheNamespace, 1)
-          task.title = `${task.title}...done.`
+        title: 'PostgreSQL pod bootstrap',
+        enabled: ctx => ctx.isPostgresDeployed && !ctx.isPostgresReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.postgresDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.postgresSelector, this.cheNamespace)
         }
       },
       {
-        title: `CodeReady Workspaces is already running in namespace \"${this.cheNamespace}\".`,
-        enabled: (ctx: any) => (ctx.isCheDeployed && ctx.isCheAvailable),
-        task: async (ctx: any, task: any) => {
-          ctx.cheDeploymentExist = true
-          ctx.cheIsAlreadyRunning = true
-          ctx.cheURL = await this.che.cheURL(this.cheNamespace)
-          task.title = await `${task.title}...it's URL is ${ctx.cheURL}`
+        title: 'Keycloak pod bootstrap',
+        enabled: ctx => ctx.isKeycloakDeployed && !ctx.isKeycloakReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.keycloakDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.keycloakSelector, this.cheNamespace)
         }
-      }
+      },
+      {
+        title: 'Devfile registry pod bootstrap',
+        enabled: ctx => ctx.isDevfileRegistryDeployed && !ctx.isDevfileRegistryReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.devfileRegistryDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.devfileRegistrySelector, this.cheNamespace)
+        }
+      },
+      {
+        title: 'Plug-in Registry pod bootstrap',
+        enabled: ctx => ctx.isPluginRegistryDeployed && !ctx.isPluginRegistryReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.pluginRegistryDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.pluginRegistrySelector, this.cheNamespace)
+        }
+      },
+      {
+        title: 'CodeReady Workspaces Dashboard pod bootstrap',
+        enabled: ctx => ctx.isDashboardDeployed && !ctx.isDashboardReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.dashboardDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.dashboardSelector, this.cheNamespace)
+        }
+      },
+      {
+        title: 'CodeReady Workspaces Server pod bootstrap',
+        enabled: ctx => ctx.isCheDeployed && !ctx.isCheReady,
+        task: async () => {
+          await this.kube.scaleDeployment(this.cheDeploymentName, this.cheNamespace, 1)
+          return this.kubeTasks.podStartTasks(this.cheSelector, this.cheNamespace)
+        }
+      },
+      ...this.checkEclipseCheStatus()
     ]
   }
 
@@ -252,18 +289,20 @@ export class CheTasks {
    */
   scaleCheDownTasks(command: Command): ReadonlyArray<Listr.ListrTask> {
     return [{
-      title: 'Stop CodeReady Workspaces server and wait until it\'s ready to shutdown',
+      title: 'Stop CodeReady Workspaces Server and wait until it\'s ready to shutdown',
       enabled: (ctx: any) => !ctx.isCheStopped,
-      task: async (ctx: any, task: any) => {
-        if (ctx.isAuthEnabled && !this.cheAccessToken) {
-          command.error('E_AUTH_REQUIRED - CodeReady Workspaces authentication is enabled and an access token need to be provided (flag --access-token). ' +
-            `For instructions to retrieve a valid access token refer to ${DOCS_LINK_AUTH_TO_CHE_SERVER_VIA_OPENID}`)
-        }
+      task: async (task: any) => {
         try {
           const cheURL = await this.che.cheURL(this.cheNamespace)
-          await this.che.startShutdown(cheURL, this.cheAccessToken)
-          await this.che.waitUntilReadyToShutdown(cheURL)
-          task.title = await `${task.title}...done`
+          const cheApi = CheApiClient.getInstance(cheURL + '/api')
+          let cheAccessToken = this.cheAccessToken
+          if (!cheAccessToken && await cheApi.isAuthenticationEnabled()) {
+            const loginManager = await CheServerLoginManager.getInstance()
+            cheAccessToken = await loginManager.getNewAccessToken()
+          }
+          await cheApi.startCheServerShutdown(cheAccessToken)
+          await cheApi.waitUntilCheServerReadyToShutdown()
+          task.title = `${task.title}...done`
         } catch (error) {
           command.error(`E_SHUTDOWN_CHE_SERVER_FAIL - Failed to shutdown CodeReady Workspaces server. ${error.message}`)
         }
@@ -281,6 +320,18 @@ export class CheTasks {
         }
       }
     },
+    {
+      title: 'Scale \"dashboard\" deployment to zero',
+      enabled: (ctx: any) => ctx.isDashboardDeployed && !ctx.isDashboardStopped,
+      task: async (_ctx: any, task: any) => {
+        try {
+          await this.kube.scaleDeployment(this.dashboardDeploymentName, this.cheNamespace, 0)
+          task.title = await `${task.title}...done`
+        } catch (error) {
+          command.error(`E_SCALE_DEPLOY_FAIL - Failed to scale dashboard deployment. ${error.message}`)
+        }
+      }
+    },
     {
       title: 'Scale \"keycloak\" deployment to zero',
       enabled: (ctx: any) => ctx.isKeycloakDeployed && !ctx.isKeycloakStopped,
@@ -369,55 +420,48 @@ export class CheTasks {
       {
         title: 'Delete configmaps for CodeReady Workspaces server and operator',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.getConfigMap('che', flags.chenamespace)) {
-            await this.kube.deleteConfigMap('che', flags.chenamespace)
-          }
-          if (await this.kube.getConfigMap('codeready-operator', flags.chenamespace)) {
-            await this.kube.deleteConfigMap('codeready-operator', flags.chenamespace)
-          }
+          await this.kube.deleteConfigMap('che', flags.chenamespace)
+          await this.kube.deleteConfigMap('codeready-operator', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
         title: 'Delete rolebindings che, che-workspace-exec and che-workspace-view',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.roleBindingExist('che', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('codeready-operator', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('codeready-operator', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace-exec', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che-workspace-exec', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace-view', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che-workspace-view', flags.chenamespace)
-          }
+          await this.kube.deleteRoleBinding('che', flags.chenamespace)
+          await this.kube.deleteRoleBinding('codeready-operator', flags.chenamespace)
+          await this.kube.deleteRoleBinding('che-workspace-exec', flags.chenamespace)
+          await this.kube.deleteRoleBinding('che-workspace-view', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
         title: 'Delete service accounts che, che-workspace',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.serviceAccountExist('che', flags.chenamespace)) {
-            await this.kube.deleteServiceAccount('che', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace', flags.chenamespace)) {
-            await this.kube.deleteServiceAccount('che-workspace', flags.chenamespace)
-          }
+          await this.kube.deleteServiceAccount('che', flags.chenamespace)
+          await this.kube.deleteServiceAccount('che-workspace', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
-        title: 'Delete PVC postgres-data and che-data-volume',
+        title: 'Delete PVCs',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.persistentVolumeClaimExist('postgres-data', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('postgres-data', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('postgres-data', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('che-data-volume', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('keycloak-data', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('keycloak-log', flags.chenamespace)
+          task.title = `${task.title}...OK`
+        }
+      },
+      {
+        title: `Delete consoleLink ${this.cheConsoleLinkName}`,
+        task: async (_ctx: any, task: any) => {
+          const checlusters = await this.kube.getAllCheClusters()
+          // Delete the consoleLink only in case if there no more checluster installed
+          if (checlusters.length === 0) {
+            await this.kube.deleteConsoleLink(this.cheConsoleLinkName)
           }
-          if (await this.kube.persistentVolumeClaimExist('che-data-volume', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('che-data-volume', flags.chenamespace)
-          }
-          task.title = await `${task.title}...OK`
+          task.title = `${task.title}...OK`
         }
       }]
   }
@@ -428,40 +472,42 @@ export class CheTasks {
   waitPodsDeletedTasks(): ReadonlyArray<Listr.ListrTask> {
     return [
       {
-        title: 'Wait until CodeReady Workspaces pod is deleted',
-        enabled: (ctx: any) => !ctx.isCheStopped,
+        title: 'Wait until CodeReady Workspaces Server pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.cheSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
         }
       },
+      {
+        title: 'Wait until CodeReady Workspaces Dashboard pod is deleted',
+        task: async (_ctx: any, task: any) => {
+          await this.kube.waitUntilPodIsDeleted(this.dashboardSelector, this.cheNamespace)
+          task.title = `${task.title}...done.`
+        }
+      },
       {
         title: 'Wait until Keycloak pod is deleted',
-        enabled: (ctx: any) => ctx.isKeycloakDeployed && !ctx.isKeycloakStopped,
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.keycloakSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
         }
       },
       {
-        title: 'Wait until Postgres pod is deleted',
-        enabled: (ctx: any) => ctx.isPostgresDeployed && !ctx.isPostgresStopped,
+        title: 'Wait until PostgreSQL pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.postgresSelector, this.cheNamespace)
           task.title = `${task.title}...done.`
         }
       },
       {
-        title: 'Wait until Devfile registry pod is deleted',
-        enabled: (ctx: any) => ctx.isDevfileRegistryDeployed && !ctx.isDevfileRegistryStopped,
+        title: 'Wait until Devfile Registry pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.devfileRegistrySelector, this.cheNamespace)
           task.title = `${task.title}...done.`
         }
       },
       {
-        title: 'Wait until Plugin registry pod is deleted',
-        enabled: (ctx: any) => ctx.isPluginRegistryDeployed && !ctx.isPluginRegistryStopped,
+        title: 'Wait until Plug-in Registry pod is deleted',
         task: async (_ctx: any, task: any) => {
           await this.kube.waitUntilPodIsDeleted(this.pluginRegistrySelector, this.cheNamespace)
           task.title = `${task.title}...done.`
@@ -470,12 +516,25 @@ export class CheTasks {
     ]
   }
 
+  deleteNamespace(flags: any): ReadonlyArray<Listr.ListrTask> {
+    return [{
+      title: `Delete namespace ${flags.chenamespace}`,
+      task: async (task: any) => {
+        const namespaceExist = await this.kube.getNamespace(flags.chenamespace)
+        if (namespaceExist) {
+          await this.kube.deleteNamespace(flags.chenamespace)
+        }
+        task.title = `${task.title}...OK`
+      }
+    }]
+  }
+
   verifyCheNamespaceExistsTask(flags: any, command: Command): ReadonlyArray<Listr.ListrTask> {
     return [{
       title: `Verify if namespace '${flags.chenamespace}' exists`,
       task: async () => {
-        if (!await this.che.cheNamespaceExist(flags.chenamespace)) {
-          command.error(`E_BAD_NS - Namespace does not exist.\nThe Kubernetes Namespace "${flags.chenamespace}" doesn't exist. The configuration cannot be injected.\nFix with: verify the namespace where workspace is running (kubectl get --all-namespaces deployment | grep workspace)`, { code: 'EBADNS' })
+        if (!await this.kube.getNamespace(flags.chenamespace)) {
+          command.error(`E_BAD_NS - Namespace does not exist.\nThe Kubernetes Namespace "${flags.chenamespace}" doesn't exist.`, { code: 'EBADNS' })
         }
       }
     }]
@@ -500,21 +559,21 @@ export class CheTasks {
     return [
       {
         title: `${follow ? 'Start following' : 'Read'} Operator logs`,
-        skip: () => flags.installer !== 'operator' && flags.installer !== 'olm',
+        skip: () => flags.installer === 'helm',
         task: async (ctx: any, task: any) => {
-          await this.che.readPodLog(flags.chenamespace, this.cheOperatorSelector, ctx.directory, follow)
+          await this.che.readPodLog(flags.chenamespace, CHE_OPERATOR_SELECTOR, ctx.directory, follow)
           task.title = `${task.title}...done`
         }
       },
       {
-        title: `${follow ? 'Start following' : 'Read'} CodeReady Workspaces logs`,
+        title: `${follow ? 'Start following' : 'Read'} CodeReady Workspaces Server logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.cheSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
         }
       },
       {
-        title: `${follow ? 'Start following' : 'Read'} Postgres logs`,
+        title: `${follow ? 'Start following' : 'Read'} PostgreSQL logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.postgresSelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
@@ -528,40 +587,30 @@ export class CheTasks {
         }
       },
       {
-        title: `${follow ? 'Start following' : 'Read'} Plugin registry logs`,
+        title: `${follow ? 'Start following' : 'Read'} Plug-in Registry logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.pluginRegistrySelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
         }
       },
       {
-        title: `${follow ? 'Start following' : 'Read'} Devfile registry logs`,
+        title: `${follow ? 'Start following' : 'Read'} Devfile Registry logs`,
         task: async (ctx: any, task: any) => {
           await this.che.readPodLog(flags.chenamespace, this.devfileRegistrySelector, ctx.directory, follow)
           task.title = await `${task.title}...done`
         }
-      }
-    ]
-  }
-
-  workspaceLogsTasks(namespace: string, workspaceId: string): ReadonlyArray<Listr.ListrTask> {
-    return [
+      },
       {
-        title: 'Read workspace logs',
+        title: `${follow ? 'Start following' : 'Read'} CodeReady Workspaces Dashboard logs`,
         task: async (ctx: any, task: any) => {
-          ctx['workspace-run'] = await this.che.readWorkspacePodLog(namespace, workspaceId, ctx.directory)
-          task.title = `${task.title}...done`
+          await this.che.readPodLog(flags.chenamespace, this.dashboardSelector, ctx.directory, follow)
+          task.title = await `${task.title}...done`
         }
-      }
-    ]
-  }
-
-  namespaceEventsTask(namespace: string, command: Command, follow: boolean): ReadonlyArray<Listr.ListrTask> {
-    return [
+      },
       {
         title: `${follow ? 'Start following' : 'Read'} namespace events`,
         task: async (ctx: any, task: any) => {
-          await this.che.readNamespaceEvents(namespace, ctx.directory, follow).catch(e => command.error(e.message))
+          await this.che.readNamespaceEvents(flags.chenamespace, ctx.directory, follow)
           task.title = await `${task.title}...done`
         }
       }
@@ -571,7 +620,7 @@ export class CheTasks {
   debugTask(flags: any): ReadonlyArray<Listr.ListrTask> {
     return [
       {
-        title: 'Find CodeReady Workspaces server pod',
+        title: 'Find CodeReady Workspaces Server pod',
         task: async (ctx: any, task: any) => {
           const chePods = await this.kube.listNamespacedPod(flags.chenamespace, undefined, this.cheSelector)
           if (chePods.items.length === 0) {
@@ -602,13 +651,73 @@ export class CheTasks {
     ]
   }
 
-  retrieveEclipseCheUrl(flags: any): ReadonlyArray<Listr.ListrTask> {
+  preparePostInstallationOutput(flags: any): ReadonlyArray<Listr.ListrTask> {
     return [
       {
-        title: 'Retrieving CodeReady Workspaces server URL',
+        title: 'Prepare post installation output',
         task: async (ctx: any, task: any) => {
-          ctx.cheURL = await this.che.cheURL(flags.chenamespace)
-          task.title = `${task.title}... ${ctx.cheURL}`
+          const messages: string[] = []
+
+          const version = await VersionHelper.getCheVersion(flags)
+          messages.push(`CodeReady Workspaces ${version.trim()} has been successfully deployed.`)
+          messages.push(`Documentation             : ${DOC_LINK}`)
+          if (DOC_LINK_RELEASE_NOTES) {
+            messages.push(`Release Notes           : ${DOC_LINK_RELEASE_NOTES}`)
+          }
+          messages.push(OUTPUT_SEPARATOR)
+
+          const cheUrl = await this.che.cheURL(flags.chenamespace)
+          messages.push(`Users Dashboard           : ${cheUrl}`)
+
+          const cr = await this.kube.getCheCluster(flags.chenamespace)
+          if (ctx.isOpenShift && cr && cr.spec && cr.spec.auth && cr.spec.auth.openShiftoAuth) {
+            if (cr.status && cr.status.openShiftOAuthUserCredentialsSecret) {
+              let user = ''
+              let password = ''
+
+              // read secret from the `openshift-config` namespace
+              let credentialsSecret = await this.kube.getSecret(cr.status.openShiftOAuthUserCredentialsSecret, 'openshift-config')
+              if (credentialsSecret) {
+                user = base64Decode(credentialsSecret.data!.user)
+                password = base64Decode(credentialsSecret.data!.password)
+              } else {
+                // read legacy secret from the `flags.chenamespace` namespace
+                credentialsSecret = await this.kube.getSecret(cr.status.openShiftOAuthUserCredentialsSecret, flags.chenamespace)
+                if (credentialsSecret) {
+                  user = base64Decode(credentialsSecret.data!.user)
+                  password = base64Decode(credentialsSecret.data!.password)
+                }
+              }
+
+              if (user && password) {
+                messages.push(`HTPasswd user credentials : "${user}:${password}".`)
+              }
+            }
+          } else {
+            messages.push('Admin user login          : "admin:admin". NOTE: must change after first login.')
+          }
+          messages.push(OUTPUT_SEPARATOR)
+
+          const cheConfigMap = await this.kube.getConfigMap('che', flags.chenamespace)
+          if (cheConfigMap && cheConfigMap.data) {
+            if (cheConfigMap.data.CHE_WORKSPACE_PLUGIN__REGISTRY__URL) {
+              messages.push(`Plug-in Registry          : ${cheConfigMap.data.CHE_WORKSPACE_PLUGIN__REGISTRY__URL}`)
+            }
+            if (cheConfigMap.data.CHE_WORKSPACE_DEVFILE__REGISTRY__URL) {
+              messages.push(`Devfile Registry          : ${cheConfigMap.data.CHE_WORKSPACE_DEVFILE__REGISTRY__URL}`)
+            }
+            messages.push(OUTPUT_SEPARATOR)
+
+            if (cheConfigMap.data.CHE_KEYCLOAK_AUTH__SERVER__URL) {
+              messages.push(`Identity Provider URL     : ${cheConfigMap.data.CHE_KEYCLOAK_AUTH__SERVER__URL}`)
+            }
+            if (ctx.identityProviderUsername && ctx.identityProviderPassword) {
+              messages.push(`Identity Provider login   : "${ctx.identityProviderUsername}:${ctx.identityProviderPassword}".`)
+            }
+            messages.push(OUTPUT_SEPARATOR)
+          }
+          ctx.highlightedMessages = messages.concat(ctx.highlightedMessages)
+          task.title = `${task.title}...done`
         }
       }
     ]
@@ -618,23 +727,13 @@ export class CheTasks {
     return [
       {
         title: 'CodeReady Workspaces status check',
-        task: async ctx => this.che.isCheServerReady(ctx.cheURL)
-      }
-    ]
-  }
-
-  checkIsAuthenticationEnabled(): ReadonlyArray<Listr.ListrTask> {
-    return [
-      {
-        title: 'Checking authentication',
-        task: async (ctx: any, task: any) => {
-          ctx.isAuthEnabled = await this.che.isAuthenticationEnabled(ctx.cheURL)
-          if (ctx.isAuthEnabled && !this.cheAccessToken) {
-            throw new Error('E_AUTH_REQUIRED - CodeReady Workspaces authentication is enabled but access token is missed. Use --access-token to provide access token.')
-          }
-          task.title = `${task.title}... ${ctx.isAuthEnabled ? '(auth enabled)' : '(auth disabled)'}`
+        task: async (ctx, task) => {
+          const cheApi = CheApiClient.getInstance(ctx.cheURL + '/api')
+          task.title = `${task.title}...done`
+          return cheApi.isCheServerReady()
         }
       }
     ]
   }
+
 }
