@@ -26,6 +26,8 @@ import { createEclipseCheCluster, createNamespaceTask, patchingEclipseCheCluster
 export class OperatorTasks {
   operatorServiceAccount = 'codeready-operator'
   cheClusterCrd = 'checlusters.org.eclipse.che'
+  cheManagerCRD = 'chemanagers.che.eclipse.org'
+  dwRoutingCRD = 'devworkspaceroutings.controller.devfile.io'
   legacyClusterResourcesName = 'codeready-operator'
 
   private getReadRolesAndBindingsTask(kube: KubeHelper): Listr.ListrTask {
@@ -172,17 +174,58 @@ export class OperatorTasks {
       {
         title: `Create CRD ${this.cheClusterCrd}`,
         task: async (ctx: any, task: any) => {
-          const exist = await kube.isCrdV1Beta1Exists(this.cheClusterCrd)
-          const yamlFilePath = path.join(ctx.resourcesPath, 'crds', 'org_v1_che_crd.yaml')
-
-          if (exist) {
-            const checkCRD = await kube.isCRDCompatible(this.cheClusterCrd, yamlFilePath)
-            if (!checkCRD) {
-              cli.error(`It is not possible to proceed the installation of CodeReady Workspaces. The existed ${this.cheClusterCrd} is different from a new one. Please update it to continue the installation.`)
-            }
+          const existedCRD = await kube.getCrd(this.cheClusterCrd)
+          if (existedCRD) {
             task.title = `${task.title}...It already exists.`
           } else {
-            await kube.createCrdV1Beta1FromFile(yamlFilePath)
+            const newCRDPath = await this.getCRDPath(ctx, flags)
+            await kube.createCrdFromFile(newCRDPath)
+            task.title = `${task.title}...done.`
+          }
+        }
+      },
+      {
+        title: `Create CRD ${this.cheManagerCRD}`,
+        task: async (ctx: any, task: any) => {
+          if (! await kube.IsAPIExtensionSupported('v1')) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const existedCRD = await kube.getCrd(this.cheManagerCRD)
+          if (existedCRD) {
+            task.title = `${task.title}...It already exists.`
+          } else {
+            const newCRDPath = path.join(ctx.resourcesPath, 'crds', 'chemanagers.che.eclipse.org.CustomResourceDefinition.yaml')
+            if (!fs.existsSync(newCRDPath)) {
+              task.title = `${task.title}...Skipped.`
+              return
+            }
+
+            await kube.createCrdFromFile(newCRDPath)
+            task.title = `${task.title}...done.`
+          }
+        }
+      },
+      {
+        title: `Create CRD ${this.dwRoutingCRD}`,
+        task: async (ctx: any, task: any) => {
+          if (! await kube.IsAPIExtensionSupported('v1')) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const existedCRD = await kube.getCrd(this.dwRoutingCRD)
+          if (existedCRD) {
+            task.title = `${task.title}...It already exists.`
+          } else {
+            const newCRDPath = path.join(ctx.resourcesPath, 'crds', 'devworkspaceroutings.controller.devfile.io.CustomResourceDefinition.yaml')
+            if (!fs.existsSync(newCRDPath)) {
+              task.title = `${task.title}...Skipped.`
+              return
+            }
+
+            await kube.createCrdFromFile(newCRDPath)
             task.title = `${task.title}...done.`
           }
         }
@@ -201,7 +244,9 @@ export class OperatorTasks {
           if (exist) {
             task.title = `${task.title}...It already exists.`
           } else {
-            await kube.createDeploymentFromFile(path.join(ctx.resourcesPath, 'operator.yaml'), flags.chenamespace, flags['che-operator-image'])
+            const deploymentPath = path.join(ctx.resourcesPath, 'operator.yaml')
+            const operatorDeployment = await this.readOperatorDeployment(deploymentPath, flags)
+            await kube.createDeploymentFrom(operatorDeployment)
             task.title = `${task.title}...done.`
           }
         }
@@ -295,17 +340,66 @@ export class OperatorTasks {
       {
         title: `Updating CodeReady Workspaces cluster CRD ${this.cheClusterCrd}`,
         task: async (ctx: any, task: any) => {
-          const crd = await kube.getCrd(this.cheClusterCrd)
-          const yamlFilePath = path.join(ctx.resourcesPath, 'crds', 'org_v1_che_crd.yaml')
-          if (crd) {
-            if (!crd.metadata || !crd.metadata.resourceVersion) {
+          const existedCRD = await kube.getCrd(this.cheClusterCrd)
+          const newCRDPath = await this.getCRDPath(ctx, flags)
+
+          if (existedCRD) {
+            if (!existedCRD.metadata || !existedCRD.metadata.resourceVersion) {
               throw new Error(`Fetched CRD ${this.cheClusterCrd} without resource version`)
             }
 
-            await kube.replaceCrdFromFile(yamlFilePath, crd.metadata.resourceVersion)
+            await kube.replaceCrdFromFile(newCRDPath, existedCRD.metadata.resourceVersion)
             task.title = `${task.title}...updated.`
           } else {
-            await kube.createCrdV1Beta1FromFile(yamlFilePath)
+            await kube.createCrdFromFile(newCRDPath)
+            task.title = `${task.title}...created new one.`
+          }
+        }
+      },
+      {
+        title: `Updating CRD ${this.cheManagerCRD}`,
+        task: async (ctx: any, task: any) => {
+          if (! await kube.IsAPIExtensionSupported('v1')) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const newCRDPath = path.join(ctx.resourcesPath, 'crds', 'chemanagers.che.eclipse.org.CustomResourceDefinition.yaml')
+          if (!fs.existsSync(newCRDPath)) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const existedCRD = await kube.getCrd(this.cheManagerCRD)
+          if (existedCRD) {
+            await kube.replaceCrdFromFile(newCRDPath, existedCRD.metadata.resourceVersion)
+            task.title = `${task.title}...updated.`
+          } else {
+            await kube.createCrdFromFile(newCRDPath)
+            task.title = `${task.title}...created new one.`
+          }
+        }
+      },
+      {
+        title: `Updating CRD ${this.dwRoutingCRD}`,
+        task: async (ctx: any, task: any) => {
+          if (! await kube.IsAPIExtensionSupported('v1')) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const newCRDPath = path.join(ctx.resourcesPath, 'crds', 'devworkspaceroutings.controller.devfile.io.CustomResourceDefinition.yaml')
+          if (!fs.existsSync(newCRDPath)) {
+            task.title = `${task.title}...Skipped.`
+            return
+          }
+
+          const existedCRD = await kube.getCrd(this.dwRoutingCRD)
+          if (existedCRD) {
+            await kube.replaceCrdFromFile(newCRDPath, existedCRD.metadata.resourceVersion)
+            task.title = `${task.title}...updated.`
+          } else {
+            await kube.createCrdFromFile(newCRDPath)
             task.title = `${task.title}...created new one.`
           }
         }
@@ -322,11 +416,12 @@ export class OperatorTasks {
         task: async (ctx: any, task: any) => {
           const exist = await kube.deploymentExist(OPERATOR_DEPLOYMENT_NAME, flags.chenamespace)
           const deploymentPath = path.join(ctx.resourcesPath, 'operator.yaml')
+          const operatorDeployment = await this.readOperatorDeployment(deploymentPath, flags)
           if (exist) {
-            await kube.replaceDeploymentFromFile(deploymentPath, flags.chenamespace, flags['che-operator-image'])
+            await kube.replaceDeploymentFrom(operatorDeployment)
             task.title = `${task.title}...updated.`
           } else {
-            await kube.createDeploymentFromFile(deploymentPath, flags.chenamespace, flags['che-operator-image'])
+            await kube.createDeploymentFrom(operatorDeployment)
             task.title = `${task.title}...created new one.`
           }
         }
@@ -403,7 +498,7 @@ export class OperatorTasks {
         if (checlusters.length > 0) {
           task.title = `${task.title}...Skipped: another CodeReady Workspaces deployment found.`
         } else {
-          await kh.deleteCrdV1Beta1(this.cheClusterCrd)
+          await kh.deleteCrd(this.cheClusterCrd)
           task.title = `${task.title}...OK`
         }
       }
@@ -469,22 +564,67 @@ export class OperatorTasks {
 
   retrieveContainerImage(deployment: V1Deployment) {
     const containers = deployment.spec!.template!.spec!.containers
-
     const namespace = deployment.metadata!.namespace
     const name = deployment.metadata!.name
-    if (containers.length === 0) {
+    const container = containers.find(c => c.name === 'codeready-operator')
+
+    if (!container) {
       throw new Error(`Can not evaluate image of ${namespace}/${name} deployment. Containers list are empty`)
     }
-
-    if (containers.length > 1) {
-      throw new Error(`Can not evaluate image of ${namespace}/${name} deployment. It has multiple containers`)
-    }
-
-    const container = containers[0]
     if (!container.image) {
       throw new Error(`Container ${container.name} in deployment ${namespace}/${name} must have image specified`)
     }
 
     return container.image
   }
+
+  async getCRDPath(ctx: any, flags: any): Promise<string> {
+    let newCRDFilePath: string
+
+    const kube = new KubeHelper(flags)
+    if (! await kube.IsAPIExtensionSupported('v1')) {
+      // try to get CRD v1beta1 if platform doesn't support v1
+      newCRDFilePath = path.join(ctx.resourcesPath, 'crds', 'org_v1_che_crd-v1beta1.yaml')
+      if (fs.existsSync(newCRDFilePath)) {
+        return newCRDFilePath
+      }
+    }
+
+    return path.join(ctx.resourcesPath, 'crds', 'org_v1_che_crd.yaml')
+  }
+
+  /**
+   * Reads and patch 'codeready-operator' deployment:
+   * - sets operator image
+   * - sets deployment namespace
+   * - removes other containers for ocp 3.11
+   */
+  private async readOperatorDeployment(path: string, flags: any): Promise<V1Deployment> {
+    const operatorDeployment = safeLoadFromYamlFile(path) as V1Deployment
+
+    if (!operatorDeployment.metadata || !operatorDeployment.metadata!.name) {
+      throw new Error(`Deployment read from ${path} must have name specified`)
+    }
+
+    if (flags['che-operator-image']) {
+      const container = operatorDeployment.spec!.template.spec!.containers.find(c => c.name === 'codeready-operator')
+      if (container) {
+        container.image = flags['che-operator-image']
+      } else {
+        throw new Error(`Container 'codeready-operator' not found in deployment '${operatorDeployment.metadata!.name}'`)
+      }
+    }
+
+    if (flags.chenamespace) {
+      operatorDeployment.metadata!.namespace = flags.chenamespace
+    }
+
+    const kube = new KubeHelper(flags)
+    if (! await kube.IsAPIExtensionSupported('v1')) {
+      const containers = operatorDeployment.spec!.template.spec!.containers || []
+      operatorDeployment.spec!.template.spec!.containers = containers.filter(c => c.name === 'codeready-operator')
+    }
+
+    return operatorDeployment
+  }
 }
